#!/usr/bin/env node
/**
 * Copyright 2019 Google LLC. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const github_release_1 = require("../github-release");
const release_pr_1 = require("../release-pr");
const candidate_issue_1 = require("../candidate-issue");
const yargs = require('yargs');
yargs
    .command('candidate-issue', 'create an issue that\'s an example of the next release', (yargs) => {
    yargs
        .option('package-name', {
        describe: 'name of package release is being minted for',
        demand: true
    })
        .option('repo-url', {
        describe: 'GitHub URL to generate release for',
        demand: true
    });
}, (argv) => __awaiter(this, void 0, void 0, function* () {
    const ci = new candidate_issue_1.CandidateIssue(argv);
    yield ci.run();
}))
    .command('release-pr', 'create a new release PR from a candidate issue', (yargs) => {
    yargs
        .option('package-name', {
        describe: 'name of package release is being minted for',
        demand: true
    })
        .option('repo-url', {
        describe: 'GitHub URL to generate release for',
        demand: true
    });
}, (argv) => __awaiter(this, void 0, void 0, function* () {
    const rp = new release_pr_1.ReleasePR(argv);
    yield rp.run();
}))
    .command('github-release', 'create a GitHub release from am release PR', (yargs) => {
    yargs.option('repo-url', { describe: 'GitHub URL to generate release for', demand: true });
}, (argv) => __awaiter(this, void 0, void 0, function* () {
    const gr = new github_release_1.GitHubRelease(argv);
    yield gr.createRelease();
}))
    .command('generate-action', 'outputs the release-please stanzas that should be added to main.workflow', (yargs) => {
    yargs.option('package-name', {
        describe: 'name of package release is being minted for',
        demand: true
    });
}, (argv) => __awaiter(this, void 0, void 0, function* () {
    console.info(chalk_1.default.green('----- put the content below in .github/main.workflow -----'));
    console.info(`workflow "Candidate Issue" {
  on = "schedule(*/5 * * * *)"
  resolves = ["candidate-issue"]
}

action "candidate-issue" {
  uses = "googleapis/release-please/.github/action/release-please@master"
  env = {
    PACKAGE_NAME = "${argv.packageName}"
    RELEASE_PLEASE_COMMAND = "candidate-issue"
  }
  secrets = ["GITHUB_TOKEN"]
}

workflow "GitHub Release" {
  on = "push"
  resolves = ["github-release"]
}

action "github-release" {
  uses = "googleapis/release-please/.github/action/release-please@master"
  env = {
    PACKAGE_NAME = "${argv.packageName}"
    RELEASE_PLEASE_COMMAND = "github-release"
  }
  secrets = ["GITHUB_TOKEN"]
}
        `);
}))
    .option('token', { describe: 'GitHub repo token', default: process.env.GH_TOKEN })
    .option('release-as', {
    describe: 'override the semantically determined release version',
    type: 'string'
})
    .option('release-type', {
    describe: 'what type of repo is a release being created for?',
    options: ['node'],
    default: 'node'
})
    .option('bump-minor-pre-major', {
    describe: 'should we bump the semver minor prior to the first major release',
    default: false,
    type: 'boolean'
})
    .option('label', {
    default: 'autorelease: pending',
    describe: 'label to add to generated PR'
})
    .demandCommand(1)
    .strict(true)
    .parse();
//# sourceMappingURL=release-please.js.map