"use strict";
/**
 * Copyright 2019 Google LLC. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const checkpoint_1 = require("./checkpoint");
// import {ConventionalCommits} from './conventional-commits';
const github_1 = require("./github");
const parseGithubRepoUrl = require('parse-github-repo-url');
class GitHubRelease {
    constructor(options) {
        this.label = options.label;
        this.repoUrl = options.repoUrl;
        this.token = options.token;
        this.changelogPath = 'CHANGELOG.md';
        this.gh = this.gitHubInstance();
    }
    createRelease() {
        return __awaiter(this, void 0, void 0, function* () {
            const gitHubReleasePR = yield this.gh.latestReleasePR(this.label);
            if (gitHubReleasePR) {
                checkpoint_1.checkpoint(`found release branch ${chalk_1.default.green(gitHubReleasePR.version)} at ${chalk_1.default.green(gitHubReleasePR.sha)}`, checkpoint_1.CheckpointType.Success);
                const changelogContents = yield this.gh.getFileContents(this.changelogPath);
                const latestReleaseNotes = GitHubRelease.extractLatestReleaseNotes(changelogContents, gitHubReleasePR.version);
                checkpoint_1.checkpoint(`found release notes: \n---\n${chalk_1.default.grey(latestReleaseNotes)}\n---\n`, checkpoint_1.CheckpointType.Success);
                yield this.gh.createRelease(gitHubReleasePR.version, gitHubReleasePR.sha, latestReleaseNotes);
                yield this.gh.removeLabel(this.label, gitHubReleasePR.number);
            }
            else {
                checkpoint_1.checkpoint('no recent release PRs found', checkpoint_1.CheckpointType.Failure);
            }
        });
    }
    gitHubInstance() {
        const [owner, repo] = parseGithubRepoUrl(this.repoUrl);
        return new github_1.GitHub({ token: this.token, owner, repo });
    }
    static extractLatestReleaseNotes(changelogContents, version) {
        version = version.replace(/^v/, '');
        const latestRe = new RegExp(`## v?\\[?${version}[^\\n]*\\n(.*?)(\\n##\\s|($(?![\r\n])))`, 'ms');
        const match = changelogContents.match(latestRe);
        if (!match) {
            throw Error('could not find changelog entry corresponding to release PR');
        }
        return match[1];
    }
}
exports.GitHubRelease = GitHubRelease;
//# sourceMappingURL=github-release.js.map