/**
 * Copyright 2019 Google LLC. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import * as Octokit from '@octokit/rest';
import { IssuesListResponseItem } from '@octokit/rest';
import { Update } from './updaters/update';
interface GitHubOptions {
    token?: string;
    owner: string;
    repo: string;
}
export interface GitHubTag {
    name: string;
    sha: string;
    version: string;
}
export interface GitHubReleasePR {
    number: number;
    version: string;
    sha: string;
}
interface GitHubPR {
    branch: string;
    version: string;
    title: string;
    body: string;
    sha: string;
    updates: Update[];
}
export declare class GitHub {
    octokit: Octokit;
    token: string | undefined;
    owner: string;
    repo: string;
    constructor(options: GitHubOptions);
    commitsSinceSha(sha: string | undefined, perPage?: number): Promise<string[]>;
    latestTag(perPage?: number): Promise<GitHubTag | undefined>;
    latestReleasePR(releaseLabel: string, perPage?: number): Promise<GitHubReleasePR | undefined>;
    private allTags;
    addLabel(pr: number, label: string): Promise<void>;
    openIssue(title: string, body: string, issue?: IssuesListResponseItem): Promise<void>;
    findExistingReleaseIssue(title: string, perPage?: number): Promise<IssuesListResponseItem | undefined>;
    openPR(options: GitHubPR): Promise<number>;
    updateFiles(updates: Update[], branch: string, refName: string): Promise<void>;
    private refByBranchName;
    getFileContents(path: string): Promise<string>;
    createRelease(version: string, sha: string, releaseNotes: string): Promise<void>;
    removeLabel(label: string, prNumber: number): Promise<void>;
}
export {};
